Changelog
=========

All notable changes to this project will be documented in this file.

The format is based on `Keep a Changelog`_,
and this project adheres to `Semantic Versioning`_.


Version 0.1.1 (2024-09-05)
--------------------------

* Added: support for Python 3.12
* Added: support for Python 3.11
* Fixed: link to Github in documentation header
* Fixed: remove links to internal documentation
  in documentation footer


Version 0.1.0 (2024-09-05)
--------------------------

* Added: initial release
* Added: ``audpsychometric.agreement_categorical()``
* Added: ``audpsychometric.agreement_numerical()``
* Added: ``audpsychometric.cronbachs_alpha()``
* Added: ``audpsychometric.congeneric_reliability()``
* Added: ``audpsychometric.evaluator_weighted_estimator()``
* Added: ``audpsychometric.intra_class_correlation()``
* Added: ``audpsychometric.list_datasets``
* Added: ``audpsychometric.mode()``
* Added: ``audpsychometric.rater_agreement()``
* Added: ``audpsychometric.read_dataset()``


.. _Keep a Changelog:
    https://keepachangelog.com/en/1.0.0/
.. _Semantic Versioning:
    https://semver.org/spec/v2.0.0.html
